PermissionNotifier class

Inheritance

Constructors

PermissionNotifier()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PermissionState
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearError() → void
clearOpeningSettings(PermissionType permission) → void
clearRequesting(PermissionType permission) → void
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reset() → void
setError(String error) → void
setLoading(bool loading) → void
setOpeningSettings(PermissionType permission) → void
Marks permission as currently waiting for the user to return from Settings, so PermissionState.uiStateFor reports PermissionUiState.openingSettings until updatePermissions (or clearOpeningSettings) clears it.
setRequesting(PermissionType permission) → void
Marks permission as currently mid-request, so PermissionState.uiStateFor reports PermissionUiState.requesting until updatePermissions (or clearRequesting) clears it.
toString() String
A string representation of this object.
inherited
updatePermissions(Map<PermissionType, PermissionResult> permissions) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited