PermissionState class
- Annotations
Constructors
-
PermissionState({required Map<
PermissionType, PermissionResult> permissions, bool isInitialized = false, bool isLoading = false, String? error}) -
const
- PermissionState.initial()
-
factory
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
final
- isLoading → bool
-
final
-
permissions
→ Map<
PermissionType, PermissionResult> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Map< PermissionType, PermissionResult> ? permissions, bool? isInitialized, bool? isLoading, Object? error}) → PermissionState -
getDeniedPermissions(
) → List< PermissionType> -
getGrantedPermissions(
) → List< PermissionType> -
isPermissionGranted(
PermissionType permission) → bool -
isPermissionPermanentlyDenied(
PermissionType permission) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited