PermissionScreenMode enum

Which flavor of full-screen page to show. Distinct from the existing dialogs — this is a real, pushable screen (see spec items #3/#4), not a popup.

Inheritance
Available extensions

Values

explanation → const PermissionScreenMode

"We need this permission and why" — shown before the OS prompt, as an alternative to PermissionInitialDialog for callers who want a full page instead of a popup.

settingsRequired → const PermissionScreenMode

"This permission is blocked, please enable it in Settings" — shown when a permission is permanently denied, as an alternative to PermissionPermanentDialog.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PermissionScreenMode>
A constant List of the values in this enum, in order of their declaration.