PermissionHandler class
Initialize the permission handler package Call this as early as possible in your app, ideally before runApp() Example:
void main() async {
WidgetsFlutterBinding.ensureInitialized();
await PermissionHandler.initialize();
runApp(MyApp());
}
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isInitialized → bool
-
Check if the package is initialized
no setter
Static Methods
-
initialize(
) → Future< void> - Initialize the permission handler package Call this before using any permission features